# Certgrinder server: certgrinderd

[![Checked with mypy](../docs/badges/mypy_badge.svg)](http://mypy-lang.org/)
[![Checked with flake8](../docs/badges/flake8-OK-green.svg)](http://flake8.pycqa.org/en/latest/)
[![Codestyle black](../docs/badges/black.svg)](https://github.com/psf/black/)
[![PyPI](https://img.shields.io/pypi/v/certgrinderd.svg)](https://pypi.org/project/certgrinderd/)
[![PyPI downloads](https://img.shields.io/pypi/dm/certgrinderd.svg)](https://pypi.org/project/certgrinderd/)

This is the server part of the [Certgrinder project](https://certgrinder.readthedocs.io/en/latest/introduction.html). The package is called ``certgrinderd``. It can be installed [from pypi](https://pypi.org/project/certgrinderd/).

It is meant to be used with the [certgrinder](https://pypi.org/project/certgrinder/) client package.

Documentation can be found at ReadTheDocs: https://certgrinder.readthedocs.io/en/latest/certgrinderd.html
